require_relative 'string/ascii_only'
require_relative 'string/blank'
require_relative 'string/format'
require_relative 'string/remove'
require_relative 'string/remove_prefix'
require_relative 'string/remove_suffix'
require_relative 'string/strip_indent'
require_relative 'string/strip_margin'
require_relative 'string/squish'
